@@ -28,6 +28,9 @@ detectionMaps <- function(CTtable,
 
   # check column names
   checkForSpacesInColumnNames(stationCol = stationCol, speciesCol = speciesCol, Xcol = Xcol, Ycol = Ycol)
+  if(class(CTtable) != "data.frame") stop("CTtable must be a data.frame", call. = FALSE)
+  if(class(recordTable) != "data.frame") stop("recordTable must be a data.frame", call. = FALSE)
+  
   if(!stationCol %in% colnames(CTtable))      stop(paste('stationCol = "',   stationCol,     '" is not a column name in CTtable', sep = ''), call. = FALSE)
   if(!stationCol %in% colnames(recordTable))  stop(paste('stationCol = "',   stationCol,     '" is not a column name in recordTable', sep = ''), call. = FALSE)
   if(!speciesCol %in% colnames(recordTable))  stop(paste('speciesCol = "', speciesCol,       '" is not a column name in recordTable', sep = ''), call. = FALSE)
